==> studiobonito-silverstripe-teams-0.11.0-13a308.zip: CHANGELOG.md <==
# Changelog

All Notable changes to `studiobonito/silverstripe-teams` will be documented in this file

## [0.11.0] - 2015-09-04
### Added
- Created extension to replace team page children with team members

### Removed
- Removed `Children()`, `isCurrent()` and `isSection()` from `TeamPage`

## [0.10.3] - 2015-08-26
### Fixed
- Update class references in TeamAdmin::$managed_models
- Check referee exists before updating backlink in TeamAdmin

## [0.10.2] - 2015-08-25
### Fixed
- Ensure TeamPage inherits parent page permissions

## [0.10.1] - 2015-08-19
### Fixed
- Update singular/plural names for TeamMember

## [0.10.0] - 2015-08-19
### Added
- Included validation for Facebook/Twitter url fields

### Changed
- Replace `FacebookId` and `TwitterId` fields with `FacebookUrl` and `TwitterUrl` fields
- Refactored all regular expression strings into class constants
- Removed `?` after domain section from regular expressions for Facebook/Twitter

### Removed
- Remove `FacebookId` and `TwitterId` fields

## [0.9.0] - 2015-08-18
### Added
- Included README.md, CHANGELOG.md, CONTRIBUTING.md and LICENSE.md
- Include singular/plural names for TeamMember
- Include support for GridFieldAddExistingAutocompleter
- Include support for GridFieldOrderableRows
- Include language file for local 'en'

### Changed
- Update keywords, homepage and installer-name in composer.json
- Namespace all classes for PSR-4
- Format all code to follow PSR-2
- Rename TeamHolder to TeamPage
- Consolidate translation strings

### Removed
- Remove support for GridFieldSortableRows

==> studiobonito-silverstripe-teams-0.12.0-b97595.zip: CHANGELOG.md <==
# Changelog

All Notable changes to `studiobonito/silverstripe-teams` will be documented in this file

## [Unreleased]

## [0.12.0] - 2015-10-08
### Added
- Included `.gitignore` file
- Included `.gitattribute` file
- Included header block in configuration file

### Changed
- Updated all `public static` properties to `private static` properties
- Prefixed `TeamAdmin` back link getter with `get`.
- Replaced custom getters on `TeamPage` with default sort on `TeamMember`

### Removed
- Deleted unused view permission on `TeamMember`

## [0.11.0] - 2015-09-04
### Added
- Created extension to replace team page children with team members

### Removed
- Removed `Children()`, `isCurrent()` and `isSection()` from `TeamPage`

## [0.10.3] - 2015-08-26
### Fixed
- Update class references in TeamAdmin::$managed_models
- Check referee exists before updating backlink in TeamAdmin

## [0.10.2] - 2015-08-25
### Fixed
- Ensure TeamPage inherits parent page permissions

## [0.10.1] - 2015-08-19
### Fixed
- Update singular/plural names for TeamMember

## [0.10.0] - 2015-08-19
### Added
- Included validation for Facebook/Twitter url fields

### Changed
- Replace `FacebookId` and `TwitterId` fields with `FacebookUrl` and `TwitterUrl` fields
- Refactored all regular expression strings into class constants
- Removed `?` after domain section from regular expressions for Facebook/Twitter

### Removed
- Remove `FacebookId` and `TwitterId` fields

## [0.9.0] - 2015-08-18
### Added
- Included README.md, CHANGELOG.md, CONTRIBUTING.md and LICENSE.md
- Include singular/plural names for TeamMember
- Include support for GridFieldAddExistingAutocompleter
- Include support for GridFieldOrderableRows
- Include language file for local 'en'

### Changed
- Update keywords, homepage and installer-name in composer.json
- Namespace all classes for PSR-4
- Format all code to follow PSR-2
- Rename TeamHolder to TeamPage
- Consolidate translation strings

### Removed
- Remove support for GridFieldSortableRows
